Index: src/core/SkMatrixImageFilter.h |
diff --git a/src/core/SkMatrixImageFilter.h b/src/core/SkMatrixImageFilter.h |
index 0631a8b8c4417a3af1a8c9ee8db00ddba3212aaf..d7745668c4a9ec08f23b97be5b52da051838032a 100644 |
--- a/src/core/SkMatrixImageFilter.h |
+++ b/src/core/SkMatrixImageFilter.h |
@@ -9,10 +9,7 @@ |
#define SkMatrixImageFilter_DEFINED |
#include "SkImageFilter.h" |
-#include "SkScalar.h" |
-#include "SkSize.h" |
-#include "SkPoint.h" |
-#include "SkPaint.h" |
+#include "SkMatrix.h" |
/*! \class SkMatrixImageFilter |
Matrix transformation image filter. This filter draws its source |
@@ -22,16 +19,15 @@ |
class SK_API SkMatrixImageFilter : public SkImageFilter { |
public: |
/** Construct a 2D transformation image filter. |
* @param transform The matrix to apply when drawing the src bitmap |
* @param filterLevel The quality of filtering to apply when scaling. |
* @param input The input image filter. If nullptr, the src bitmap |
* passed to filterImage() is used instead. |
*/ |
static SkMatrixImageFilter* Create(const SkMatrix& transform, |
- SkFilterQuality, |
+ SkFilterQuality filterQuality, |
SkImageFilter* input = nullptr); |
- virtual ~SkMatrixImageFilter(); |
SkRect computeFastBounds(const SkRect&) const override; |
@@ -44,8 +40,8 @@ protected: |
SkImageFilter* input); |
void flatten(SkWriteBuffer&) const override; |
- bool onFilterImageDeprecated(Proxy*, const SkBitmap& src, const Context&, |
- SkBitmap* result, SkIPoint* loc) const override; |
+ sk_sp<SkSpecialImage> onFilterImage(SkSpecialImage* source, const Context&, |
+ SkIPoint* offset) const override; |
SkIRect onFilterNodeBounds(const SkIRect& src, const SkMatrix&, MapDirection) const override; |
private: |
@@ -22,16 +19,15 @@ |
public: |
/** Construct a 2D transformation image filter. |
- * @param transform The matrix to apply when drawing the src bitmap |
- * @param filterLevel The quality of filtering to apply when scaling. |
- * @param input The input image filter. If nullptr, the src bitmap |
- * passed to filterImage() is used instead. |
+ * @param transform The matrix to apply when drawing the src bitmap |
+ * @param filterQuality The quality of filtering to apply when scaling. |
+ * @param input The input image filter. If nullptr, the src bitmap |
+ * passed to filterImage() is used instead. |
*/ |
static SkMatrixImageFilter* Create(const SkMatrix& transform, |